Index: /trunk/psModules/test/tst_pmObjects01.c
===================================================================
--- /trunk/psModules/test/tst_pmObjects01.c	(revision 4101)
+++ /trunk/psModules/test/tst_pmObjects01.c	(revision 4102)
@@ -19,6 +19,6 @@
  * abd never deallocate, no error is generated.
  *
- *  @version $Revision: 1.8 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-03 21:43:17 $
+ *  @version $Revision: 1.9 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-03 22:45:51 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -49,5 +49,5 @@
                               {test03, 001, "pmObjects: pmCullPeaks()", true, false},
                               {test04, 001, "pmObjects: pmSourceLocalSky()", true, false},
-                              {test06, 001, "pmObjects: pmSourceSetPixelCircle()", true, false},
+                              {test06, 001, "pmObjects: pmSourceSetPixelsCircle()", true, false},
                               {test05, 001, "pmObjects: pmSourceMoments()", true, false},
                               {test07, 001, "pmObjects: pmMin()", true, false},
@@ -1101,8 +1101,8 @@
 
     printf("----------------------------------------------------------------------------------\n");
-    printf("Calling pmSourceSetPixelCircle with NULL psSource.  Should generate error and return NULL.\n");
-    rc = pmSourceSetPixelCircle(NULL, imgData, 10.0);
+    printf("Calling pmSourceSetPixelsCircle with NULL psSource.  Should generate error and return NULL.\n");
+    rc = pmSourceSetPixelsCircle(NULL, imgData, 10.0);
     if (rc == true) {
-        printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
+        printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
         testStatus = false;
     }
@@ -1110,24 +1110,24 @@
 
     printf("----------------------------------------------------------------------------------\n");
-    printf("Calling pmSourceSetPixelCircle with NULL psImage.  Should generate error and return NULL.\n");
-    rc = pmSourceSetPixelCircle(tmpSource, NULL, 10.0);
+    printf("Calling pmSourceSetPixelsCircle with NULL psImage.  Should generate error and return NULL.\n");
+    rc = pmSourceSetPixelsCircle(tmpSource, NULL, 10.0);
     if (rc == true) {
-        printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
-        testStatus = false;
-    }
-
-    printf("----------------------------------------------------------------------------------\n");
-    printf("Calling pmSourceSetPixelCircle with wrong type psImage.  Should generate error and return NULL.\n");
-    rc = pmSourceSetPixelCircle(tmpSource, imgDataF64, 10.0);
+        printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
+        testStatus = false;
+    }
+
+    printf("----------------------------------------------------------------------------------\n");
+    printf("Calling pmSourceSetPixelsCircle with wrong type psImage.  Should generate error and return NULL.\n");
+    rc = pmSourceSetPixelsCircle(tmpSource, imgDataF64, 10.0);
     if (rc == true) {
-        printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
-        testStatus = false;
-    }
-
-    printf("----------------------------------------------------------------------------------\n");
-    printf("Calling pmSourceSetPixelCircle with radius < 0.0.  Should generate error and return NULL.\n");
-    rc = pmSourceSetPixelCircle(tmpSource, imgData, -10.0);
+        printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
+        testStatus = false;
+    }
+
+    printf("----------------------------------------------------------------------------------\n");
+    printf("Calling pmSourceSetPixelsCircle with radius < 0.0.  Should generate error and return NULL.\n");
+    rc = pmSourceSetPixelsCircle(tmpSource, imgData, -10.0);
     if (rc == true) {
-        printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
+        printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
         testStatus = false;
     }
@@ -1135,58 +1135,58 @@
     /* XXX: Commented away since the EAM mods no longer produced errors.
         printf("----------------------------------------------------------------------------------\n");
-        printf("Calling pmSourceSetPixelCircle with subImage startCol < 0.  Should generate error and return NULL.\n");
+        printf("Calling pmSourceSetPixelsCircle with subImage startCol < 0.  Should generate error and return NULL.\n");
         tmpSource->peak->x = (psF32) (TST06_NUM_ROWS / 2);
         tmpSource->peak->y = (psF32) (TST06_NUM_COLS / 2);
         tmpSource->peak->x = 1;
-        rc = pmSourceSetPixelCircle(tmpSource, imgData, 10.0);
+        rc = pmSourceSetPixelsCircle(tmpSource, imgData, 10.0);
         if (rc == true) {
-            printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
+            printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
             testStatus = false;
         }
      
         printf("----------------------------------------------------------------------------------\n");
-        printf("Calling pmSourceSetPixelCircle with subImage endCol > numCols.  Should generate error and return NULL.\n");
+        printf("Calling pmSourceSetPixelsCircle with subImage endCol > numCols.  Should generate error and return NULL.\n");
         tmpSource->peak->x = (psF32) (TST06_NUM_ROWS / 2);
         tmpSource->peak->y = (psF32) (TST06_NUM_COLS / 2);
         tmpSource->peak->x = TST06_NUM_COLS;
-        rc = pmSourceSetPixelCircle(tmpSource, imgData, 10.0);
+        rc = pmSourceSetPixelsCircle(tmpSource, imgData, 10.0);
         if (rc == true) {
-            printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
+            printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
             testStatus = false;
         }
      
         printf("----------------------------------------------------------------------------------\n");
-        printf("Calling pmSourceSetPixelCircle with subImage startRow < 0.  Should generate error and return NULL.\n");
+        printf("Calling pmSourceSetPixelsCircle with subImage startRow < 0.  Should generate error and return NULL.\n");
         tmpSource->peak->x = (psF32) (TST06_NUM_ROWS / 2);
         tmpSource->peak->y = (psF32) (TST06_NUM_COLS / 2);
         tmpSource->peak->y = 1;
-        rc = pmSourceSetPixelCircle(tmpSource, imgData, 10.0);
+        rc = pmSourceSetPixelsCircle(tmpSource, imgData, 10.0);
         if (rc == true) {
-            printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
+            printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
             testStatus = false;
         }
      
         printf("----------------------------------------------------------------------------------\n");
-        printf("Calling pmSourceSetPixelCircle with subImage endRow > numRows.  Should generate error and return NULL.\n");
+        printf("Calling pmSourceSetPixelsCircle with subImage endRow > numRows.  Should generate error and return NULL.\n");
         tmpSource->peak->x = (psF32) (TST06_NUM_ROWS / 2);
         tmpSource->peak->y = (psF32) (TST06_NUM_COLS / 2);
         tmpSource->peak->y = TST06_NUM_ROWS;
-        rc = pmSourceSetPixelCircle(tmpSource, imgData, 10.0);
+        rc = pmSourceSetPixelsCircle(tmpSource, imgData, 10.0);
         if (rc == true) {
-            printf("TEST ERROR: pmSourceSetPixelCircle() returned TRUE.\n");
+            printf("TEST ERROR: pmSourceSetPixelsCircle() returned TRUE.\n");
             testStatus = false;
         }
     */
     printf("----------------------------------------------------------------------------------\n");
-    printf("Calling pmSourceSetPixelCircle with valid data.\n");
+    printf("Calling pmSourceSetPixelsCircle with valid data.\n");
     tmpSource->peak->x = (psF32) (TST06_NUM_ROWS / 2);
     tmpSource->peak->y = (psF32) (TST06_NUM_COLS / 2);
-    rc = pmSourceSetPixelCircle(tmpSource, imgData, 10.0);
+    rc = pmSourceSetPixelsCircle(tmpSource, imgData, 10.0);
 
     if (rc == false) {
-        printf("TEST ERROR: pmSourceSetPixelCircle() returned FALSE.\n");
+        printf("TEST ERROR: pmSourceSetPixelsCircle() returned FALSE.\n");
         testStatus = false;
     } else {
         // XXX: Test correctness of the various psSetPixelCircle members.
     }
 
@@ -1135,58 +1135,58 @@
         testStatus = false;
     } else {
-        // XXX: Test correctness of the various psSetPixelCircle members.
+        // XXX: Test correctness of the various psSetPixelsCircle members.
     }
 
